[![Build Status](https://travis-ci.org/grburgess/responsum.svg?branch=master)](https://travis-ci.org/grburgess/responsum)
[![codecov](https://codecov.io/gh/grburgess/responsum/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/responsum)
# responsum
A python library for dealing with energy dispersion style responses. This is heavily modeled (and taken from) the [3ML](https://github.com/threeML) reponse functionality, but for much of my work I need to handle responses and do not want to depend on 3ML as it is a large library. 
